@@ -6,15 +6,11 @@ use base qw/MojoMojo::Formatter/;
 use HTML::Entities;
 
 eval "use Syntax::Highlight::Engine::Kate;";
-my $eval_res=$@;
-
+my $eval_res = $@;
 sub module_loaded { $eval_res ? 0 : 1 }
 
-
 my $main_formatter;
-eval {
-    $main_formatter = MojoMojo->pref('main_formatter');
-};
+eval { $main_formatter = MojoMojo->pref('main_formatter'); };
 $main_formatter ||= 'MojoMojo::Formatter::Markdown';
 
 =head1 NAME
@@ -48,7 +44,7 @@ has to be highlighted, do:
 
  <pre lang="Perl">
    say "Hola Mundo";
- </pre> 
+ </pre>
 
 See L<Syntax::Highlight::Engine::Kate/PLUGINS> for a list of supported
 languages.
@@ -68,26 +64,35 @@ sub format_content {
     my $ph      = 0;
     my $ph_base = __PACKAGE__ . '::PlaceHolder::';
 
-    # new school - consistent with other new syntax, but broke for me to the point of exhaustion
-    # $$content =~ s/\{\{\s*code\s+lang=""\s*\}\}/<pre>/g;
-    # while ( $$content =~ s/\{\{\s*code(?:\s+lang=['"]*(.*?)['"]*")?\s*\}\}(.*?)\{\{\s*end\s*\}\}/$ph_base$ph/si ) {
-    # old school - which works with textile2 (not textile for mxh)
-    # drop all lang=""
+# new school - consistent with other new syntax, but broke for me to the point of exhaustion
+# $$content =~ s/\{\{\s*code\s+lang=""\s*\}\}/<pre>/g;
+# while ( $$content =~ s/\{\{\s*code(?:\s+lang=['"]*(.*?)['"]*")?\s*\}\}(.*?)\{\{\s*end\s*\}\}/$ph_base$ph/si ) {
+# old school - which works with textile2 (not textile for mxh)
+# drop all lang=""
     $$content =~ s/<\s*pre\s+lang=""\s*>/<pre>/g;
     while ( $$content =~ s/<\s*pre(?:\s+lang=['"]*(.*?)['"]*")?\s*>(.*?)<\s*\/pre\s*>/$ph_base$ph/si ) {
-        my ($language, $block) = ($1, $2);
+        my ( $language, $block ) = ( $1, $2 );
+
         # Fix newline issue
         $block =~ s/\r//g;
 
-        # Unfortunately markdown also encodes entities at some level which is not possible to disable
-        # neither easy to hack like we do for textile. So let's decode &amp; to & to avoid:
-        # &gt; => &amp;gt;
+# Unfortunately markdown also encodes entities at some level which is not possible to disable
+# neither easy to hack like we do for textile. So let's decode &amp; to & to avoid:
+# &gt; => &amp;gt;
         $block =~ s/&amp;/&/g;
 
         $block = decode_entities($block);
         if ($language) {
             eval {
                 $kate->language($language);
+                if ( $language eq 'HTML' ) {
+
+                    # We want HTML entities for HTML Hightlight
+                    # Yeah, this is sub-optimal.
+                    $kate->substitutions->{"<"} = "&lt;";
+                    $kate->substitutions->{">"} = "&gt;";
+                    $kate->substitutions->{"&"} = "&amp";
+                }
             };
             unless ($@) {
                 $block = $kate->highlightText($block);
@@ -97,7 +102,7 @@ sub format_content {
         $ph++;
     }
 
-    for (my $i=0; $i<$ph; $i++) {
+    for ( my $i = 0 ; $i < $ph ; $i++ ) {
         $$content =~ s/$ph_base$i/<pre>$blocks[$i]<\/pre>/;
     }
 
@@ -113,26 +118,28 @@ sub _kate {
             "\n" => "\n",
         },
         format_table => {
-            Alert        => [ q{<span class="kateAlert">},           "</span>" ],
-            BaseN        => [ q{<span class="kateBaseN">},           "</span>" ],
-            BString      => [ q{<span class="kateBString">},         "</span>" ],
-            Char         => [ q{<span class="kateChar">},            "</span>" ],
-            Comment      => [ q{<span class="kateComment"><i>},      "</i></span>" ],
-            DataType     => [ q{<span class="kateDataType">},        "</span>" ],
-            DecVal       => [ q{<span class="kateDecVal">},          "</span>" ],
-            Error        => [ q{<span class="kateError"><b><i>},     "</i></b></span>" ],
-            Float        => [ q{<span class="kateFloat">},           "</span>" ],
-            Function     => [ q{<span class="kateFunction">},        "</span>" ],
-            IString      => [ q{<span class="kateIString">},         "" ],
-            Keyword      => [ q{<b>},                            "</b>" ],
-            Normal       => [ q{},                               "" ],
-            Operator     => [ q{<span class="kateOperator">},        "</span>" ],
-            Others       => [ q{<span class="kateOthers">},          "</span>" ],
-            RegionMarker => [ q{<span class="kateRegionMarker"><i>}, "</i></span>" ],
-            Reserved     => [ q{<span class="kateReserved"><b>},     "</b></span>" ],
-            String       => [ q{<span class="kateString">},          "</span>" ],
-            Variable     => [ q{<span class="kateVariable"><b>},     "</b></span>" ],
-            Warning      => [ q{<span class="kateWarning"><b><i>},   "</b></i></span>" ],
+            Alert    => [ q{<span class="kateAlert">},      "</span>" ],
+            BaseN    => [ q{<span class="kateBaseN">},      "</span>" ],
+            BString  => [ q{<span class="kateBString">},    "</span>" ],
+            Char     => [ q{<span class="kateChar">},       "</span>" ],
+            Comment  => [ q{<span class="kateComment"><i>}, "</i></span>" ],
+            DataType => [ q{<span class="kateDataType">},   "</span>" ],
+            DecVal   => [ q{<span class="kateDecVal">},     "</span>" ],
+            Error => [ q{<span class="kateError"><b><i>}, "</i></b></span>" ],
+            Float => [ q{<span class="kateFloat">},       "</span>" ],
+            Function => [ q{<span class="kateFunction">}, "</span>" ],
+            IString  => [ q{<span class="kateIString">},  "" ],
+            Keyword  => [ q{<b>},                         "</b>" ],
+            Normal   => [ q{},                            "" ],
+            Operator => [ q{<span class="kateOperator">}, "</span>" ],
+            Others   => [ q{<span class="kateOthers">},   "</span>" ],
+            RegionMarker =>
+              [ q{<span class="kateRegionMarker"><i>}, "</i></span>" ],
+            Reserved => [ q{<span class="kateReserved"><b>}, "</b></span>" ],
+            String   => [ q{<span class="kateString">},      "</span>" ],
+            Variable => [ q{<span class="kateVariable"><b>}, "</b></span>" ],
+            Warning =>
+              [ q{<span class="kateWarning"><b><i>}, "</b></i></span>" ],
         },
     );
 }
