@@ -19,13 +19,7 @@ sub new {
 
     my ( $c, $arg_ref ) = @_;
 
-    my $theme=$c->config->{theme} ||= 'default';
-    unless(-d  $c->path_to('root','themes',$theme)) {
-        $c->log->info(
-            $c->path_to('root','themes',$theme) . " does not exist" );
-    }
     $class->config->{INCLUDE_PATH}=[
-        $c->path_to('root','themes',$theme),
         $c->path_to('root'),
         $c->path_to('root','base'),
     ];
